@@ -6,12 +6,12 @@ Business::GoCardless - Perl library for interacting with the GoCardless Basic v1
 (https://gocardless.com)
 
 =for html
-<a href='https://travis-ci.org/leejo/business-gocardless?branch=master'><img src='https://travis-ci.org/leejo/business-gocardless.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/leejo/business-gocardless?branch=master'><img src='https://coveralls.io/repos/leejo/business-gocardless/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/G3S/business-gocardless?branch=master'><img src='https://travis-ci.org/G3S/business-gocardless.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/G3S/business-gocardless?branch=master'><img src='https://coveralls.io/repos/G3S/business-gocardless/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.11
+0.12
 
 =head1 DESCRIPTION
 
@@ -490,7 +490,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation,
 features, bug fixes, or anything else then please raise an issue / pull request:
 
-    https://github.com/leejo/business-gocardless
+    https://github.com/G3S/business-gocardless
 
 =cut
 
